@@ -38,6 +38,8 @@ class SharedData:
             self.s3write=False
             mode = 'r'
         
+        self.save_local = (os.environ['SAVE_LOCAL']=='True')
+        
         self.mode = mode
             
         # DATA DICTIONARY
@@ -72,30 +74,15 @@ class SharedData:
     def getSymbols(self, collection):        
         return self.getMetadata(collection).static.index.values
 
-    def mergeUpdate(self,newdf):
-        ddidx = newdf.index.duplicated()
-        if ddidx.any():
-            newdf = newdf[~newdf.index.duplicated(keep='first')]            
-            Logger.log.warning('Metadata merge duplicated index for new dataframe!')
-        
-        ddidx = self.static.index.duplicated()        
-        if ddidx.any():
-            self.static = self.static[~self.static.index.duplicated(keep='first')]            
-            Logger.log.warning('Metadata merge duplicated index for static dataframe!')
-
-        newcolsidx = ~newdf.columns.isin(self.static.columns)
-        if newcolsidx.any():
-            newcols = newdf.columns[newcolsidx]
-            for c in newcols:
-                self.static.loc[:,c] = newdf[c]                
-
+    def mergeUpdate(self,newdf):        
         newidx = ~newdf.index.isin(self.static.index)
         if newidx.any():
             self.static = self.static.reindex(index=self.static.index.union(newdf.index))
 
-        newcol = ~newdf.columns.isin(self.static.columns)
-        if newcol.any():
-            self.static = self.static.reindex(columns=self.static.columns.union(newdf.columns))
+        newcolsidx = ~newdf.columns.isin(self.static.columns)
+        if newcolsidx.any():
+            newcols = newdf.columns[newcolsidx]            
+            self.static = pd.concat([self.static,newdf[newcols]],axis=1)
             
         self.static.update(newdf)
   
