@@ -2,7 +2,6 @@ import os
 import logging
 import subprocess
 import boto3
-import awscli
 from pathlib import Path
 import pandas as pd
 from datetime import datetime,timedelta
@@ -22,7 +21,7 @@ class KinesisLogStreamHandler(logging.StreamHandler):
         self.stream_buffer = []
 
         try:
-            session = boto3.Session()
+            session = boto3.Session(profile_name=os.environ['LOG_AWS_PROFILE'])
             if 'KINESIS_ENDPOINT_URL' in os.environ:
                 self.datastream = session.client('kinesis',\
                     endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
@@ -124,7 +123,7 @@ class KinesisLogStreamConsumer():
         return self.dflogs
     
     def connect(self):
-        session = boto3.Session()
+        session = boto3.Session(profile_name=os.environ['LOG_AWS_PROFILE'])
         if 'KINESIS_ENDPOINT_URL' in os.environ:            
             self.client = session.client('kinesis',\
                 endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
@@ -214,7 +213,7 @@ class KinesisStreamProducer():
         self.datastream = None
         self.stream_buffer = []
         try:
-            session = boto3.Session()
+            session = boto3.Session(profile_name=os.environ['STREAM_AWS_PROFILE'])
             if 'KINESIS_ENDPOINT_URL' in os.environ:
                 self.datastream = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
             else:
@@ -254,7 +253,7 @@ class KinesisStreamConsumer():
 
     def get_stream(self):
         print('Initializing stream...')
-        session = boto3.Session()
+        session = boto3.Session(profile_name=os.environ['STREAM_AWS_PROFILE'])
         if 'KINESIS_ENDPOINT_URL' in os.environ:
             self.client = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
         else:
