@@ -43,7 +43,7 @@ class SharedDataRealTime:
     def getProducer(shdata):
         if not shdata.database in SharedDataRealTime.producer.keys():
             streamname = os.environ['BASE_STREAM_NAME']+'-'+shdata.database.lower()
-            session = boto3.Session()
+            session = boto3.Session(profile_name=os.environ['STREAM_AWS_PROFILE'])
             client = session.client('kinesis')
             #create stream
             try:
